@@ -1,5 +1,6 @@
 use super::{arc::ArcBuffer, number::Number};
-use std::{cmp::max, str::from_utf8_unchecked};
+use alloc::{string::String, vec::Vec};
+use core::{cmp::max, str::from_utf8_unchecked};
 
 #[pen_ffi_macro::any(crate = "crate")]
 #[repr(C)]
